@@ -8,10 +8,8 @@ use cogo::std::sync::mpsc::{bounded, channel, channel_buf, unbounded};
 
 
 fn main() {
-    // let (s, r) = unbounded();//unbounded
-    // let (s, r) = bounded(3); //bounded
-    //let (s, r) = chan!(2);//bounded
     let (s, r) = chan!();//unbounded
+    let s1 = s.clone();
     go!(move ||{
          let t=std::time::Instant::now();
          println!("send1");
